<?php
    require_once('AccelerometerData.php');

    class AccelerometerDataManager
    {
        const HOST = "localhost";
        const DB = "AccelerometerData";
        const USER = "accelerometer";
        const PW = "accelerometer";

        public function readLatest()
        {
            $retVal = NULL;

            $db = new PDO("mysql:host=" . self::HOST . ";dbname=" . self::DB, self::USER, self::PW);
            $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

            // Get the latest measurement
            $sql = "SELECT id, created, axis_x, axis_y, axis_z FROM accelerometer_data ORDER BY id DESC LIMIT 1";

            try
            {
                $query = $db->prepare($sql);
                $query->execute();

                $results = $query->fetchAll(PDO::FETCH_CLASS, "AccelerometerData");

                if (is_array($results) && count($results) == 1)
                {
                    return $this->getJsonEncodedDataFromAccelDataObjects($results);
                }
                else
                {
                    $retVal = 0;
                    $retVal = json_encode($retVal, JSON_PRETTY_PRINT);
                }
            }
            catch(Exception $ex)
            {
                echo "{$ex->getMessage()}<br/>\n";
            }

            return $retVal;
        }

        public function readFromIdToLatest($id)
        {
            $retVal = NULL;

            $db = new PDO("mysql:host=" . self::HOST . ";dbname=" . self::DB, self::USER, self::PW);
            $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

            // Get the 'created' date from the given id
            $sql = "SELECT id, created, axis_x, axis_y, axis_z FROM accelerometer_data WHERE id > :id ORDER BY id";

            try
            {
                $query = $db->prepare($sql);
                $query->bindParam(":id", $id, PDO::PARAM_INT);
                $query->execute();

                $results = $query->fetchAll(PDO::FETCH_CLASS, "AccelerometerData");

                if (is_array($results) && count($results) >= 1)
                {
                    return $this->getJsonEncodedDataFromAccelDataObjects($results);
                }
                else
                {
                    $retVal = $this->readLatest(); // Just get the latest reading
                }
            }
            catch(Exception $ex)
            {
                echo "{$ex->getMessage()}<br/>\n";
            }

            return $retVal;
        }

        private function getJsonEncodedDataFromAccelDataObjects($accelDataObjects)
        {
            $measurements = array();

            foreach ($accelDataObjects as $accel)
            {
                $measurements[] = array('axis' => array('X' => $accel->axis_x,
                                                'Y' => $accel->axis_y,
                                                'Z' => $accel->axis_z),
                                'dateTime' => $accel->created);
            }

            $accelerationData = array('accelerationData' =>
                                    array('accelerationMeasurements' => $measurements,
                                          'lastMeasurementId' => $accel->id)
                                );

            return json_encode($accelerationData, JSON_PRETTY_PRINT);
        }
    }
